@@ -36,14 +36,14 @@ class PreviewWidget : public QFrame, Ui::preview
 
 public:
     PreviewWidget(QWidget *parent);
-    virtual ~PreviewWidget();
+    ~PreviewWidget() override;
 
     void setPalette(const KSharedConfigPtr &config,
                     QPalette::ColorGroup state = QPalette::Active);
 
 protected:
     void setPaletteRecursive(QWidget*, const QPalette&);
-    bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *, QEvent *) override;
 };
 
 #endif
